@@ -15,14 +15,14 @@ class Direction(Printable, Enum):
         v: str = value.upper()
         return Direction[v]
 
-    def __str__(self) -> str:
+    def value(self) -> str:
         return self.name.lower()
 
 
 def main() -> None:
     print(Direction.to_enum("down"))
     print(Direction.to_enum("neutral"))
-    print(Direction.UP)
+    print(Direction.UP.value())
 
 
 if __name__ == "__main__":
